==> egov-common-1.0.5-sources.jar: com/gtis/plat/vo/PfTaskAgentVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * @(#)PfTaskAgent.java 2010-7-7 14:23:46
 * Copy Right Information	: 南京国图
 * Project 					:
 * JDK version used		    : jdk1.5.0_20
 * Comments					: 任务代理对象
 * Version					:
 * CreateAuthor             : ShiHui
 */
public class PfTaskAgentVo implements Serializable {

    private static final long serialVersionUID = -6053098752263554017L;

    /**
     * 主键
     */
    private String taskAgentId;
    /**
     * 代理用户
     */
    private String userId;
    /**
     * 被代理的用户
     */
    private String agentUserId;
    /**
     * 需代理的工作流Id
     */
    private String workFlowDefinitionId;
    /**
     * 需代理的工作流活动Id
     */
    private String activityDefinitionId;
    /**
     * 代理开始时间
     */
    private Date beginTime;
    /**
     * 结束时间
     */
    private Date endTime;
    /**
     * 备注
     */
    private String remark;

    public String getTaskAgentId() {
        return taskAgentId;
    }

    public void setTaskAgentId(String taskAgentId) {
        this.taskAgentId = taskAgentId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getWorkFlowDefinitionId() {
        return workFlowDefinitionId;
    }

    public void setWorkFlowDefinitionId(String workFlowDefinitionId) {
        this.workFlowDefinitionId = workFlowDefinitionId;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getAgentUserId() {
        return agentUserId;
    }

    public void setAgentUserId(String agentUserId) {
        this.agentUserId = agentUserId;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> egov-common-1.1.9-sources.jar: com/gtis/plat/vo/PfTaskAgentVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * @(#)PfTaskAgent.java 2010-7-7 14:23:46
 * Copy Right Information	: 南京国图
 * Project 					:
 * JDK version used		    : jdk1.5.0_20
 * Comments					: 任务代理对象
 * Version					:
 * CreateAuthor             : ShiHui
 */
public class PfTaskAgentVo implements Serializable {

    private static final long serialVersionUID = -6053098752263554017L;

    /**
     * 主键
     */
    private String taskAgentId;
    /**
     * 代理用户
     */
    private String userId;
    /**
     * 被代理的用户
     */
    private String agentUserId;
    /**
     * 需代理的工作流Id
     */
    private String workFlowDefinitionId;
    /**
     * 需代理的工作流活动Id
     */
    private String activityDefinitionId;
    /**
     * 代理开始时间
     */
    private Date beginTime;
    /**
     * 结束时间
     */
    private Date endTime;
    /**
     * 备注
     */
    private String remark;

    /**
     * 代理类型
     */
    private int agentType;

    public int getAgentType() {
        return agentType;
    }

    public void setAgentType(int agentType) {
        this.agentType = agentType;
    }

    public String getTaskAgentId() {
        return taskAgentId;
    }

    public void setTaskAgentId(String taskAgentId) {
        this.taskAgentId = taskAgentId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getWorkFlowDefinitionId() {
        return workFlowDefinitionId;
    }

    public void setWorkFlowDefinitionId(String workFlowDefinitionId) {
        this.workFlowDefinitionId = workFlowDefinitionId;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getAgentUserId() {
        return agentUserId;
    }

    public void setAgentUserId(String agentUserId) {
        this.agentUserId = agentUserId;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}
